@@ -31,7 +31,7 @@ class GroupSortProxy : public QSortFilterProxyModel
 
     public:
         explicit GroupSortProxy(AbstractModel *parentModel, QAbstractItemModel *sourceModel);
-        ~GroupSortProxy();
+        ~GroupSortProxy() override;
 
     protected:
         bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
@@ -43,7 +43,7 @@ class InvalidAppsFilterProxy : public QSortFilterProxyModel
 
     public:
         explicit InvalidAppsFilterProxy(AbstractModel *parentModel, QAbstractItemModel *sourceModel);
-        ~InvalidAppsFilterProxy();
+        ~InvalidAppsFilterProxy() override;
 
     protected:
         bool filterAcceptsRow(int source_row, const QModelIndex & source_parent) const override;
@@ -68,10 +68,10 @@ class RecentUsageModel : public ForwardingModel, public QQmlParserStatus
         enum Ordering { Recent, Popular };
 
         explicit RecentUsageModel(
-                QObject *parent = 0,
+                QObject *parent = nullptr,
                 IncludeUsage usage = AppsAndDocs,
                 int ordering = Recent);
-        ~RecentUsageModel();
+        ~RecentUsageModel() override;
 
         QString description() const override;
 
