@@ -29,29 +29,6 @@
 
 #include <X11/extensions/XInput2.h>
 
-static const QSet<QString> configProps = {
-    QStringLiteral("enabled"),
-    QStringLiteral("disableWhileTyping"),
-    QStringLiteral("disableEventsOnExternalMouse"),
-    QStringLiteral("leftHanded"),
-    QStringLiteral("middleEmulation"),
-    QStringLiteral("pointerAcceleration"),
-    QStringLiteral("pointerAccelerationProfileFlat"),
-    QStringLiteral("pointerAccelerationProfileAdaptive"),
-    QStringLiteral("tapToClick"),
-    QStringLiteral("tapAndDrag"),
-    QStringLiteral("tapDragLock"),
-    QStringLiteral("lrmTapButtonMap"),
-    QStringLiteral("lmrTapButtonMap"),
-    QStringLiteral("scrollTwoFinger"),
-    QStringLiteral("scrollOnButtonDown"),
-    QStringLiteral("scrollButton"),
-    QStringLiteral("scrollEdge"),
-    QStringLiteral("naturalScroll"),
-    QStringLiteral("horizontalScrolling"),
-    QStringLiteral("clickMethodAreas"),
-    QStringLiteral("clickMethodClickfinger")
-};
 
 const Parameter libinputProperties[] = {
 
@@ -389,6 +366,16 @@ bool LibinputTouchpad::isChangedConfig()
     return changed;
 }
 
+int LibinputTouchpad::touchpadOff()
+{
+    return m_enabled.val;
+}
+
+XcbAtom &LibinputTouchpad::touchpadOffAtom()
+{
+    return *m_atoms[QLatin1Literal("enabled")].data();
+}
+
 template<typename T>
 bool LibinputTouchpad::valueLoader(Prop<T> &prop)
 {
